@@ -4,8 +4,8 @@
 ;; Description: Nimbus dark theme
 ;; Author:      Marcin Swieczkowski <marcin@realemail.net>
 ;; Created:     Thu Mar 2 22:19:19 CET 2017
-;; Package-Version: 20251201.2205
-;; Package-Revision: fb35c0c89e7d
+;; Package-Version: 20260112.41
+;; Package-Revision: 1ee3e643a011
 ;; Package-Requires: ((emacs "24.1"))
 ;; URL:         https://github.com/mrcnski/nimbus-theme
 ;; Keywords:    faces
@@ -745,7 +745,7 @@
    `(hl-line ((t (:background ,hl-line :extend t))))
 
    ;; hl-todo
-   `(hl-todo ((t (:foreground ,pink :bold nil :slant italic))))
+   `(hl-todo ((t (:foreground ,light-orange :bold nil :slant italic))))
 
    ;; idle-highlight-mode
    `(idle-highlight ((t (:inherit highlight))))
